[vlc-commits] ttml: rename OpenDemux/CloseDemux functions

Thomas Guillem git at videolan.org
Sat Nov 11 11:02:02 CET 2017


vlc | branch: master | Thomas Guillem <thomas at gllm.fr> | Sat Nov 11 10:45:36 2017 +0100| [55b3cfc79f6c2c1e0e6acc02f81494799d61ab66] | committer: Thomas Guillem

ttml: rename OpenDemux/CloseDemux functions

This fixes duplicate symbols with a static build

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=55b3cfc79f6c2c1e0e6acc02f81494799d61ab66
---

 modules/codec/ttml/substtml.c | 8 ++++----
 modules/codec/ttml/ttml.c     | 4 ++--
 modules/codec/ttml/ttml.h     | 8 ++++----
 modules/demux/ttml.c          | 6 +++---
 4 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/modules/codec/ttml/ttml.c b/modules/codec/ttml/ttml.c
index 24b1050d5a..c66a1214f2 100644
--- a/modules/codec/ttml/ttml.c
+++ b/modules/codec/ttml/ttml.c
@@ -43,7 +43,7 @@ vlc_module_begin ()
     set_capability( "spu decoder", 10 )
     set_shortname( N_("TTML decoder"))
     set_description( N_("TTML subtitles decoder") )
-    set_callbacks( OpenDecoder, CloseDecoder )
+    set_callbacks( tt_OpenDecoder, tt_CloseDecoder )
     set_category( CAT_INPUT )
     set_subcategory( SUBCAT_INPUT_SCODEC )
     add_integer( "ttml-align", 0, ALIGN_TEXT, ALIGN_LONGTEXT, false )
@@ -54,7 +54,7 @@ vlc_module_begin ()
         set_capability( "demux", 3 )
         set_category( CAT_INPUT )
         set_subcategory( SUBCAT_INPUT_DEMUX )
-        set_callbacks( OpenDemux, CloseDemux )
+        set_callbacks( tt_OpenDemux, tt_CloseDemux )
         add_shortcut( "ttml" )
 
 vlc_module_end ()
diff --git a/modules/codec/ttml/ttml.h b/modules/codec/ttml/ttml.h
index 51f41126f9..1add96635f 100644
--- a/modules/codec/ttml/ttml.h
+++ b/modules/codec/ttml/ttml.h
@@ -18,11 +18,11 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
-int OpenDemux( vlc_object_t* p_this );
-void CloseDemux( demux_t* p_demux );
+int tt_OpenDemux( vlc_object_t* p_this );
+void tt_CloseDemux( demux_t* p_demux );
 
-int  OpenDecoder   ( vlc_object_t * );
-void CloseDecoder  ( vlc_object_t * );
+int  tt_OpenDecoder   ( vlc_object_t * );
+void tt_CloseDecoder  ( vlc_object_t * );
 
 enum
 {
diff --git a/modules/demux/ttml.c b/modules/demux/ttml.c
index a22cbb6a79..bc4f8cdbe0 100644
--- a/modules/demux/ttml.c
+++ b/modules/demux/ttml.c
@@ -391,7 +391,7 @@ static int Demux( demux_t* p_demux )
     return VLC_DEMUXER_SUCCESS;
 }
 
-int OpenDemux( vlc_object_t* p_this )
+int tt_OpenDemux( vlc_object_t* p_this )
 {
     demux_t     *p_demux = (demux_t*)p_this;
     demux_sys_t *p_sys;
@@ -530,12 +530,12 @@ int OpenDemux( vlc_object_t* p_this )
     return VLC_SUCCESS;
 
 error:
-    CloseDemux( p_demux );
+    tt_CloseDemux( p_demux );
 
     return VLC_EGENERIC;
 }
 
-void CloseDemux( demux_t* p_demux )
+void tt_CloseDemux( demux_t* p_demux )
 {
     demux_sys_t* p_sys = p_demux->p_sys;
 



More information about the vlc-commits mailing list
diff --git a/modules/codec/ttml/substtml.c b/modules/codec/ttml/substtml.c
index bd82623d66..585a5f16b3 100644
--- a/modules/codec/ttml/substtml.c
+++ b/modules/codec/ttml/substtml.c
@@ -1089,9 +1089,9 @@ static int DecodeBlock( decoder_t *p_dec, block_t *p_block )
 }
 
 /*****************************************************************************
  * OpenDecoder: probe the decoder and return score
  *****************************************************************************/
-int OpenDecoder( vlc_object_t *p_this )
+int tt_OpenDecoder( vlc_object_t *p_this )
 {
     decoder_t *p_dec = (decoder_t*)p_this;
     decoder_sys_t *p_sys;
@@ -1111,9 +1111,9 @@ int OpenDecoder( vlc_object_t *p_this )
 }
 
 /*****************************************************************************
  * CloseDecoder: clean up the decoder
  *****************************************************************************/
-void CloseDecoder( vlc_object_t *p_this )
+void tt_CloseDecoder( vlc_object_t *p_this )
 {
     decoder_t *p_dec = (decoder_t *)p_this;
     decoder_sys_t *p_sys = p_dec->p_sys;
@@ -1089,9 +1089,9 @@ static int DecodeBlock( decoder_t *p_dec, block_t *p_block )
 
 /*****************************************************************************
- * OpenDecoder: probe the decoder and return score
+ * tt_OpenDecoder: probe the decoder and return score
  *****************************************************************************/
@@ -1111,9 +1111,9 @@ int OpenDecoder( vlc_object_t *p_this )
 
 /*****************************************************************************
- * CloseDecoder: clean up the decoder
+ * tt_CloseDecoder: clean up the decoder
  *****************************************************************************/